==> nextcloud-12.0.2.tgz: nextcloud/apps/gallery/l10n/es_MX.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galería",
    "There was a problem reading files from this album" : "Se presentó un problema al leer los archivos de este álbum",
    "Aborting preview. Could not find the file" : "Abortando vista previa. No fue posible encontrar el archivo",
    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server url" : "URL del servidor inválido",
    "Could not load the description" : "No fue posible cargar la descripción",
    "Could not load the description: " : "No fue posible cargar la descripción:",
    "Copyright" : "Derechos de autor",
    "Could not load the copyright notice: " : "No fue posible cargar el aviso de derechos de autor:",
    "Copyright notice" : "Aviso de derechos de autor",
    "Link to copyright document" : "Liga al documento de derechos de autor",
    "This application may not work properly on your browser." : "Esta aplicación puede no funcionar correctamente en tu navegador. ",
    "For an improved experience, please install one of the following alternatives" : "Para una mejor experienca, por favor instala una de las siguientes alternativas",
    "Your browser is not supported!" : "¡Tu navegador no está soportado!",
    "please install one of the following alternatives" : "por favor instala alguna de las siguientes alternativas",
    "Album cannot be shown" : "No se puede mostrar el álbum",
    "No media files found" : "No se encontraron archivos de medios",
    "Upload pictures in the Files app to display them here" : "Cargar imágenes in la aplicación de Archivos para que se desplieguen aquí",
    "Upload new files via drag and drop or by using the [+] button above" : "Carga archivos nuevos ya sea arrastrándolos o bien usando el botón [+] de arriba",
    "Configuration error" : "Error de configuración",
    "New" : "Nuevo",
    "Hide Album" : "Ocultar álbum",
    "Could not hide album" : "No fue posible ocultar el álbum",
    "Error loading slideshow template" : "Se presentó un error al cargar la plantilla de presentación",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>¡Error!</strong> No fue posible generar la vista previa de este archivo. <br>Por favor ve a la siguiente imagen mientras quitamos ésta del carrusel ",
    "Next" : "Siguiente",
    "Play" : "Reproducir",
    "Pause" : "Pausar",
    "Previous" : "Anterior",
    "Close" : "Cerrar",
    "Download" : "Descargar",
    "Toggle background" : "Alternar el fondo",
    "Delete" : "Borrar",
    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo \"{file}\" porque ya existe",
    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es in tipo de archivo permitido",
    "Upload" : "Cargar",
    "Error" : "Error",
    "Error while sharing" : "Se presentó un error al compartir",
    "Error while unsharing" : "Se presentó un error al dejar de compartir",
    "Error while changing permissions" : "Se presentó un error al cambiar los permisos",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y con el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "Share with users or groups …" : "Compartir con otros usuarios o grupos ...",
    "Share with users, groups or remote users …" : "Compartir con otros usuarios, grupos o usuarios remotos...",
    "Share" : "Compartir",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Comparte con personas en otros servidores usando tu ID de nube federada username@example.com/cloud",
    "Share link" : "Compartir liga",
    "The public link will expire no later than {days} days after it is created" : "La liga pública expirará a los {days} días de haber sido creada",
    "Link" : "Liga",
    "Password protect" : "Proteger con contraseña",
    "Password" : "Contraseña",
    "Choose a password for the public link" : "Selecciona una contraseña para la liga pública",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enviar liga por correo electrónico a una persona",
    "Send" : "Enviar",
    "Set expiration date" : "Establecer fecha de expiración",
    "Expiration" : "Expiración",
    "Expiration date" : "Fecha de expiración",
    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar trucnada - por favor refina tu búsqueda para poder ver más resultados. ",
    "No users or groups found for {search}" : "No se encontraron usuarios o grupos para {search}",
    "No users found for {search}" : "No se encontraron usuarios para {search}",
    "An error occured. Please try again" : "Se presentó un error. Por favor intenta de nuevo",
    "Adding user..." : "Agregando usuario ...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Error while retrieving shares" : "Se presentó un error al recuperar los recursos compartidos",
    "Unshare" : "Dejar de compartir",
    "notify by email" : "notificar por correo electrónico",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "access control" : "control de acceso",
    "create" : "crear",
    "change" : "cambiar",
    "delete" : "borrar",
    "Password protected" : "Protegido con contraseña",
    "Error unsetting expiration date" : "Se presentó un error al quitar la fecha de expiración",
    "Error setting expiration date" : "Se presentó un error al establecer fecha de expiración",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Warning" : "Advertencia",
    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtalo de nuevo.",
    "Sort by date" : "Ordenar por fecha",
    "Sort by name" : "Ordenar por nombre",
    "Cancel upload" : "Cancelar carga",
    "Album information" : "Información del álbum",
    "File list" : "Lista de archivos",
    "Sorry, this file could not be found." : "Lo sentimos, no fue posible encontrar este archivo. ",
    "Reasons might be:" : "Las razones podrían ser:",
    "the wrong file ID was provided" : "Proporcionaste un ID de archivo equivocado",
    "the file was removed" : "El archivo fue eliminado",
    "the file is corrupt" : "El archivo está corrupto",
    "the encryption key is missing" : "Falta la llave de encripción",
    "Here is the error message returned by the server: " : "Aquí está el mensaje de error que regresó el servidor:",
    "For more information, please contact your friendly Nextcloud administrator." : "Para mayor información, por favor contactaa a tu cordial administrador de Nextcloud. ",
    "Sorry, but the server could not fulfill your request." : "Lo sentimos, pero el servidor no pudo completar tu solicitud. ",
    "Possible reasons for the problem:" : "Razones posibles del problema:",
    "a conflicting app was installed" : "se instaló una aplicación que está generando un conflicto",
    "a required component is missing or was disconnected" : "un componente requerido está faltando o fue desconectado",
    "the filesystem is not readable" : "no se puede leer el sistema de archivos",
    "Sorry, this link doesn't seem to work anymore." : "Lo sentimos, parece que esta liga ya no funciona. ",
    "the item was removed" : "el elemento fue eliminado",
    "the link has expired" : "La liga ha expirado",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more information, please ask the person who has sent you this link." : "Para mayor información, por favor consulta a la persona que te envió esta liga.",
    "Add to your Nextcloud" : "Agregar a tu Nextcloud",
    "Picture view" : "Vista de imágenes",
    "Gallery view" : "Vista de galería"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/es_MX.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galería",
    "There was a problem reading files from this album" : "Se presentó un problema al leer los archivos de este álbum",
    "Aborting preview. Could not find the file" : "Abortando vista previa. No fue posible encontrar el archivo",
    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server url" : "URL del servidor inválido",
    "Could not load the description" : "No fue posible cargar la descripción",
    "Could not load the description: " : "No fue posible cargar la descripción:",
    "Copyright" : "Derechos de autor",
    "Could not load the copyright notice: " : "No fue posible cargar el aviso de derechos de autor:",
    "Copyright notice" : "Aviso de derechos de autor",
    "Link to copyright document" : "Liga al documento de derechos de autor",
    "This application may not work properly on your browser." : "Esta aplicación puede no funcionar correctamente en tu navegador. ",
    "For an improved experience, please install one of the following alternatives" : "Para una mejor experienca, por favor instala una de las siguientes alternativas",
    "Your browser is not supported!" : "¡Tu navegador no está soportado!",
    "please install one of the following alternatives" : "por favor instala alguna de las siguientes alternativas",
    "Album cannot be shown" : "No se puede mostrar el álbum",
    "No media files found" : "No se encontraron archivos de medios",
    "Upload pictures in the Files app to display them here" : "Cargar imágenes en la aplicación de Archivos para que se desplieguen aquí",
    "Upload new files via drag and drop or by using the [+] button above" : "Carga archivos nuevos ya sea arrastrándolos o bien usando el botón [+] de arriba",
    "Configuration error" : "Error de configuración",
    "New" : "Nuevo",
    "Hide Album" : "Ocultar álbum",
    "Could not hide album" : "No fue posible ocultar el álbum",
    "Error loading slideshow template" : "Se presentó un error al cargar la plantilla de presentación",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>¡Error!</strong> No fue posible generar la vista previa de este archivo. <br>Por favor ve a la siguiente imagen mientras quitamos ésta del carrusel ",
    "Next" : "Siguiente",
    "Play" : "Reproducir",
    "Pause" : "Pausar",
    "Previous" : "Anterior",
    "Close" : "Cerrar",
    "Download" : "Descargar",
    "Toggle background" : "Alternar el fondo",
    "Delete" : "Borrar",
    "Share" : "Compartir",
    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo \"{file}\" porque ya existe",
    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es in tipo de archivo permitido",
    "Upload" : "Cargar",
    "Error" : "Error",
    "Error while sharing" : "Se presentó un error al compartir",
    "Error while unsharing" : "Se presentó un error al dejar de compartir",
    "Error while changing permissions" : "Se presentó un error al cambiar los permisos",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y con el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "Share with users or groups …" : "Compartir con otros usuarios o grupos ...",
    "Share with users, groups or remote users …" : "Compartir con otros usuarios, grupos o usuarios remotos...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Comparte con personas en otros servidores usando tu ID username@example.com/cloud",
    "Share link" : "Compartir liga",
    "The public link will expire no later than {days} days after it is created" : "La liga pública expirará a los {days} días de haber sido creada",
    "Link" : "Liga",
    "Password protect" : "Proteger con contraseña",
    "Password" : "Contraseña",
    "Choose a password for the public link" : "Selecciona una contraseña para la liga pública",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enviar liga por correo electrónico a una persona",
    "Send" : "Enviar",
    "Set expiration date" : "Establecer fecha de expiración",
    "Expiration" : "Expiración",
    "Expiration date" : "Fecha de expiración",
    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar trucnada - por favor refina tu búsqueda para poder ver más resultados. ",
    "No users or groups found for {search}" : "No se encontraron usuarios o grupos para {search}",
    "No users found for {search}" : "No se encontraron usuarios para {search}",
    "An error occured. Please try again" : "Se presentó un error. Por favor intenta de nuevo",
    "Adding user..." : "Agregando usuario ...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Error while retrieving shares" : "Se presentó un error al recuperar los recursos compartidos",
    "Unshare" : "Dejar de compartir",
    "notify by email" : "notificar por correo electrónico",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "access control" : "control de acceso",
    "create" : "crear",
    "change" : "cambiar",
    "delete" : "borrar",
    "Password protected" : "Protegido con contraseña",
    "Error unsetting expiration date" : "Se presentó un error al quitar la fecha de expiración",
    "Error setting expiration date" : "Se presentó un error al establecer fecha de expiración",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Warning" : "Advertencia",
    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtalo de nuevo.",
    "Sort by name" : "Ordenar por nombre",
    "Sort by date" : "Ordenar por fecha",
    "Cancel upload" : "Cancelar carga",
    "Album information" : "Información del álbum",
    "File list" : "Lista de archivos",
    "Sorry, this file could not be found." : "Lo sentimos, no fue posible encontrar este archivo. ",
    "Reasons might be:" : "Las razones podrían ser:",
    "the wrong file ID was provided" : "Proporcionaste un ID de archivo equivocado",
    "the file was removed" : "El archivo fue eliminado",
    "the file is corrupt" : "El archivo está corrupto",
    "the encryption key is missing" : "Falta la llave de encripción",
    "Here is the error message returned by the server: " : "Aquí está el mensaje de error que regresó el servidor:",
    "For more information, please contact your friendly Nextcloud administrator." : "Para mayor información, por favor contactaa a tu cordial administrador de Nextcloud. ",
    "Sorry, but the server could not fulfill your request." : "Lo sentimos, pero el servidor no pudo completar tu solicitud. ",
    "Possible reasons for the problem:" : "Razones posibles del problema:",
    "a conflicting app was installed" : "se instaló una aplicación que está generando un conflicto",
    "a required component is missing or was disconnected" : "un componente requerido está faltando o fue desconectado",
    "the filesystem is not readable" : "no se puede leer el sistema de archivos",
    "Sorry, this link doesn't seem to work anymore." : "Lo sentimos, parece que esta liga ya no funciona. ",
    "the item was removed" : "el elemento fue eliminado",
    "the link has expired" : "La liga ha expirado",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more information, please ask the person who has sent you this link." : "Para mayor información, por favor consulta a la persona que te envió esta liga.",
    "Add to your Nextcloud" : "Agregar a tu Nextcloud",
    "Picture view" : "Vista de imágenes",
    "Gallery view" : "Vista de galería",
    "Sending ..." : "Enviando..."
},
"nplurals=2; plural=(n != 1);");
